@@ -11,11 +11,11 @@ Regexp::Pattern::License - Regular expressions for legal licenses
 
 =head1 VERSION
 
-Version v3.0.28
+Version v3.0.30
 
 =cut
 
-our $VERSION = version->declare("v3.0.28");
+our $VERSION = version->declare("v3.0.30");
 
 =head1 DESCRIPTION
 
@@ -46,6 +46,8 @@ Patterns each covering a single license.
 
 =item * artistic
 
+=item * artistic_2
+
 =item * beerware
 
 =item * bsd_2_clause
@@ -208,12 +210,18 @@ our %RE = (
 	afl => {
 		name    => 'AFL',
 		summary => 'Academic Free License',
-		pat     => qr/$the?(?:Academic Free License(?: \(AFL\))?|AFL)/,
+		pat => qr/(?:$the?Academic Free License(?: \(AFL\))?|${the}AFL\b)/,
 	},
 	agpl => {
 		name    => 'AGPL',
 		summary => 'GNU Affero General Public License',
-		pat     => qr/$the?$gnu?(?:Affero $gpl(?: \(AGPL\))?$by_fsf?|AGPL)/,
+		pat =>
+			qr/(?:$the?$gnu?Affero $gpl(?: \(AGPL\))?$by_fsf?|(?:$the$gnu?|$gnu)AGPL)/,
+	},
+	aladdin => {
+		name    => 'Aladdin',
+		summary => 'Aladdin Free Public License',
+		pat     => qr/$the?Aladdin Free Public License/,
 	},
 	apache => {
 		name    => 'Apache',
@@ -231,6 +239,11 @@ our %RE = (
 		summary => 'Artistic License',
 		pat     => qr/$the?Artistic License/,
 	},
+	artistic_2 => {
+		name    => 'Artistic-2.0',
+		summary => 'Artistic License (v2.0)',
+		pat     => qr/is governed by this Artistic License\./,
+	},
 	beerware => {
 		name    => 'Beerware',
 		summary => 'Beer-Ware License',
@@ -243,7 +256,7 @@ our %RE = (
 		caption               => 'BSD (2 clause)',
 		tags                  => ['bsd'],
 		pat =>
-			qr/$P{note_repro_notice_cond_discl}\b[^a-zA-Z]+$P{asis_sw_by_name}/,
+			qr/$P{repro_copr_cond_discl}\W+$P{asis_sw_by_name}/,
 	},
 	bsd_3_clause => {
 		name                  => 'BSD-3-Clause',
@@ -251,14 +264,14 @@ our %RE = (
 		caption               => 'BSD (3 clause)',
 		tags                  => ['bsd'],
 		pat =>
-			qr/$P{note_repro_notice_cond_discl}\b[^a-zA-Z]+$P{nopromo_neither}/,
+			qr/$P{repro_copr_cond_discl}\W+$P{nopromo_neither}/,
 	},
 	bsd_4_clause => {
 		name                  => 'BSD-4-Clause',
 		'name.alt.org.debian' => 'BSD-4-clause',
 		caption               => 'BSD (4 clause)',
 		tags                  => ['bsd'],
-		pat                   => qr/$P{ad_verbatim}/,
+		pat                   => qr/$P{ad_mat_ack_this}/,
 	},
 	cc_by => {
 		name    => 'CC-BY',
@@ -330,7 +343,7 @@ our %RE = (
 		name    => 'CDDL',
 		summary => 'Common Development and Distribution License',
 		pat =>
-			qr/$the?(?:(?:Common Development and Distribution License|COMMON DEVELOPMENT AND DISTRIBUTION LICENSE)(?: \(CDDL\))?|CDDL)/,
+			qr/(?:$the?(?:Common Development and Distribution License|COMMON DEVELOPMENT AND DISTRIBUTION LICENSE)(?: \(CDDL\))?|${the}CDDL\b)/,
 	},
 	cecill => {
 		name    => 'CECILL',
@@ -378,11 +391,11 @@ our %RE = (
 		name => 'Cube',
 		tags => ['zlib'],
 		pat =>
-			qr/$P{origin_no_misrepresent}.*?$P{derive_altermark}.*?$P{note_invar}.*?$P{derive_no_relicense}/,
+			qr/$P{origin_sw_no_misrepresent}; $P{you_not_claim_wrote}\. $P{use_ack_nonreq}\. $P{altered_srcver_mark}\. $P{notice_no_alter_any}\. additional clause specific to Cube:? $P{src_no_relicense}/,
 	},
 	curl => {
 		tags => ['mit'],
-		pat  => qr/$P{note_cpyr_perm}\.\s+$P{asis_sw_warranty}/,
+		pat  => qr/$P{note_copr_perm}\.\s+$P{asis_sw_warranty}/,
 	},
 	dsdp => {
 		name                     => 'DSDP',
@@ -393,13 +406,13 @@ our %RE = (
 	epl => {
 		name    => 'EPL',
 		summary => 'Eclipse Public License',
-		pat     => qr/$the?(?:Eclipse Public License(?: \(EPL\))?|EPL)/,
+		pat => qr/(?:$the?Eclipse Public License(?: \(EPL\))?|${the}EPL\b)/,
 	},
 	eurosym => {
 		name => 'Eurosym',
 		tags => ['zlib'],
 		pat =>
-			qr/$P{origin_no_misrepresent}.*?$P{derive_altermark}.*?$P{derive_share}.*?$P{note_invar}/,
+			qr/$P{origin_sw_no_misrepresent}.*?$P{altered_srcver_mark}.*?$P{change_redist_share}.*?$P{notice_no_alter}/,
 	},
 	fsfap => {
 		name    => 'FSFAP',
@@ -420,13 +433,14 @@ our %RE = (
 	ftl => {
 		name    => 'FTL',
 		caption => 'Freetype',
-		pat     => qr/$the?(?:FreeType project license(?: \(FTL\))?|FTL)/,
+		pat =>
+			qr/$the?(?:FreeType(?: [Pp]roject)? (?:LICENSE|[Ll]icense)(?: \(FTL\))?)/,
 	},
 	gfdl => {
 		name    => 'GFDL',
 		summary => 'GNU Free Documentation License',
 		pat =>
-			qr/$the?$gnu?(?:Free Documentation License(?: \(GFDL\))?$by_fsf?|GFDL)/,
+			qr/(?:$the?$gnu?Free Documentation License(?: \(GFDL\))?$by_fsf?|(?:$the$gnu?|$gnu)GFDL)/,
 	},
 	gfdl_niv => {
 		name    => 'GFDL-NIV',
@@ -434,56 +448,93 @@ our %RE = (
 		summary =>
 			'GNU Free Documentation License, with no Front-Cover or Back-Cover Texts or Invariant Sections',
 		pat =>
-			qr/$the?$gnu?(?:Free Documentation License(?: \(GFDL\))?$by_fsf?[,;]? $niv|GFDL-NIV)/,
+			qr/(?:$the?$gnu?Free Documentation License(?: \(GFDL\))?$by_fsf?[,;]? $niv|(?:$the$gnu?|$gnu)GFDL-NIV)/,
 	},
 	gpl => {
 		name    => 'GPL',
 		summary => 'The GNU General Public License',
-		pat     => qr/$the?$gnu?(?:$gpl(?: \(GPL\))?$by_fsf?|GPL)/,
+		pat =>
+			qr/(?:$the?$gnu?$gpl(?: \(GPL\))?$by_fsf?|(?:$the$gnu?|$gnu)GPL)/,
 	},
 	isc => {
 		name => 'ISC',
 		tags => ['mit'],
-		pat  => qr/$P{note_cpyr_perm}\.\s+$P{asis_sw_name_discl}/,
+		pat  => qr/$P{note_copr_perm}\.\s+$P{asis_sw_name_discl}/,
 	},
 	icu => {
 		name => 'ICU',
 		tags => ['mit'],
 		pat =>
-			qr/$P{note_cpyr_perm} of the Software and that $P{note_cpyr_perm_doc}\.\s+$P{asis_sw_warranty}(?:[^.]+\.\s+){2}$P{nopromo_except}/,
+			qr/$P{note_copr_perm} of the Software and that $P{repro_copr_perm_appear_doc}\.\s+$P{asis_sw_warranty}(?:[^.]+\.\s+){2}$P{nopromo_except}/,
 	},
 	lgpl => {
 		name    => 'LGPL',
 		summary => 'The GNU Lesser General Public License',
 		pat =>
-			qr/$the?$gnu?(?:(?:Library|Lesser(?: \(Library\))?) $gpl(?: \(LGPL\))?$by_fsf?|LGPL)/,
+			qr/(?:$the?$gnu?(?:Library|Lesser(?: \(Library\))?) $gpl(?: \(LGPL\))?$by_fsf?|(?:$the$gnu?|$gnu)LGPL)/,
 	},
 	llgpl => {
 		name    => 'LLGPL',
 		summary => 'Lisp Lesser General Public License',
-		pat     => qr/$the?(?:Lisp Lesser $gpl(?: \(LLGPL\))?|\bLLGPL\b)/,
+		pat     => qr/(?:$the?Lisp Lesser $gpl(?: \(LLGPL\))?|${the}LLGPL\b)/,
 	},
 	libpng => {
 		name => 'Libpng',
-		pat  => qr/$the?libpng license/,
+		pat =>
+			qr/$P{origin_src_no_misrepresent}\. $P{altered_ver_mark}\. $P{copr_no_alter}/,
 	},
 	mit_advertising => {
 		name    => 'MIT-advertising',
 		caption => 'MIT (advertising)',
 		tags    => ['mit'],
-		pat     => qr/$P{note_marketing}\b[^.,]+, and $P{ad_ack_doc_sw}/,
+		pat => qr/$P{note_marketing}\b[^.,]+, and $P{ack_doc_mat_pkg_use}/,
+	},
+	mit_cmu => {
+		name        => 'MIT-CMU',
+		description => <<'END',
+Identical to NTP, except...
+ * omit explicit permission for charging fee
+ * exclude suitability disclaimer
+ * exclude terse "as is" warranty disclaimer
+ * include elaborate warranty disclaimer
+ * include liability disclaimer
+
+fingerprint: "without specific written permission"
+
+SPDX and fedora sample seem not generic but the unique file COPYING from project net-snmp.
+END
+		tags => ['mit'],
+		pat =>
+			qr/Permission $P{to_dist} $P{sw_doc} $P{any_purpose} and $P{nofee} $P{granted}, $P{retain_copr_appear} and that $P{repro_copr_perm_appear_doc}, and that $P{nopromo_name_written}\./,
+	},
+	mit_cmu_warranty => {
+		'name.alt.org.debian'    => 'MIT-CMU~warranty',
+		caption                  => 'MIT (CMU, retain warranty disclaimer)',
+		'caption.alt.org.fedora' => 'MIT (MLton / Standard ML of New Jersey)',
+		description              => <<'END',
+Identical to MIT-CMU, except...
+ * add requirement of "warranty disclaimer" appearing in documentation
+
+fingerprint: "warranty disclaimer appear"
+END
+		tags => ['mit'],
+		pat =>
+			qr/Permission $P{to_dist} $P{sw_doc} $P{any_purpose} and $P{nofee} $P{granted}, $P{retain_copr_appear} and that $P{repro_copr_perm_warr_appear_doc}, and that $P{nopromo_name_written_prior}\./,
 	},
 	mit_enna => {
 		name    => 'MIT-enna',
 		caption => 'MIT (enna)',
 		tags    => ['mit'],
-		pat     => qr/$P{ad_pub_ack_nosrc}/,
+		pat     => qr/$P{ack_pub_use_nosrc}/,
+		pat =>
+			qr/$P{perm_granted}, $P{free_charge}, $P{to_pers} $P{the_sw}, $P{to_deal_the_sw_rights} $P{to_mod_sublic} $P{sw}, and $P{to_perm_pers}, $P{subj_cond}:? $P{retain_copr_perm_sw_copr}\. $P{ack_pub_use_nosrc}\. This includes acknowledgments in either Copyright notices, Manuals, Publicity and Marketing documents or any documentation provided with any product containing this software\. $P{license_not_lib}\./,
 	},
 	mit_feh => {
 		name    => 'MIT-feh',
 		caption => 'MIT (feh)',
 		tags    => ['mit'],
-		pat     => qr/$P{ad_ack_doc_pkg}/,
+		pat =>
+			qr/$P{perm_granted}, $P{free_charge}, $P{to_pers} $P{the_sw}, $P{to_deal_the_sw_rights} $P{to_mod_sublic} $P{sw}, and $P{to_perm_pers}, $P{subj_cond}:? $P{retain_copr_perm_sw_doc} and $P{ack_doc_pkg_use}\./,
 	},
 	mit_new => {
 		'name.alt.org.spdx'      => 'MIT',
@@ -492,21 +543,22 @@ our %RE = (
 		'caption.alt.org.debian' => 'MIT/X11 (BSD like)',
 		'caption.alt.org.fedora' => 'MIT (Modern Style with sublicense)',
 		tags                     => ['mit'],
-		pat => qr/$P{right_mod_sublic}\b[^.]+\s+$P{note_cpyr_perm_subst}/,
+		pat =>
+			qr/$P{to_mod_sublic} $P{sw}\b[^.]+\s+$P{retain_copr_perm_subst}/,
 	},
 	mit_new_materials => {
 		'name.alt.org.debian' => 'MIT~Khronos',
 		caption               => 'MIT (Khronos)',
 		tags                  => ['mit'],
 		pat =>
-			qr/$P{permission_person_materials}, $P{permission_use_deal_materials}/,
+			qr/$P{perm_granted}, $P{free_charge}, $P{to_pers} $P{the_material}, $P{to_deal_mat}/,
 	},
 	mit_old => {
 		'name.alt.org.debian' => 'MIT~old',
 		'name.alt.org.gentoo' => 'Old-MIT',
 		caption               => 'MIT (old)',
 		tags                  => ['mit'],
-		pat                   => qr/$P{permission_granted_agree_fee}/,
+		pat                   => qr/$P{perm_granted}, $P{free_agree_fee}/,
 	},
 	mit_oldstyle => {
 		'name.alt.org.debian' => 'MIT~oldstyle',
@@ -526,25 +578,25 @@ END
 	mit_oldstyle_permission => {
 		'name.alt.org.debian' => 'MIT~oldstyle~permission',
 		tags                  => ['mit'],
-		pat => qr/$P{nopromo_written_prior}\.\s+$P{asis_name_sw}/,
+		pat => qr/$P{without_written_prior}\.\s+$P{asis_name_sw}/,
 	},
 	mpl => {
 		name    => 'MPL',
 		summary => 'Mozilla Public License',
 		pat =>
-			qr/$the?(?:Mozilla Public License(?: \(\"?(?:https?:?\/\/mozilla.org\/)?MPL\"?\))?(?: (?:as )?published by $the{0,2}Mozilla Foundation)?|MPL)/,
+			qr/(?:$the?Mozilla Public License(?: \(\"?(?:https?:?\/\/mozilla.org\/)?MPL\"?\))?(?: (?:as )?published by $the{0,2}Mozilla Foundation)?|${the}MPL\b)/,
 	},
 	ms_pl => {
 		name    => 'MS-PL',
 		caption => 'Ms-PL',
 		pat =>
-			qr/$the?(?:Microsoft Permissive License(?: \(Ms-PL\))?|Ms-PL)/,
+			qr/(?:$the?Microsoft Public License(?: \(Ms-PL\))?|${the}Ms-PL\b)/,
 	},
 	ms_rl => {
 		name    => 'MS-RL',
 		caption => 'Ms-RL',
 		pat =>
-			qr/$the?(?:Microsoft Reciprocal License(?: \(Ms-RL\))?|Ms-RL)/,
+			qr/(?:$the?Microsoft Reciprocal License(?: \(Ms-RL\))?|${the}Ms-RL\b)/,
 	},
 	ntp => {
 		name => 'NTP',
@@ -560,7 +612,7 @@ END
 	openssl => {
 		name    => 'OpenSSL',
 		summary => 'OpenSSL License',
-		pat     => qr/$P{ad_always}/,
+		pat     => qr/$P{redist_ack_this}/,
 	},
 	postgresql => {
 		name => 'PostgreSQL',
@@ -572,6 +624,12 @@ END
 		caption => 'Public domain',
 		pat     => qr/$the?public domain/,
 	},
+	ofl => {
+		name                     => 'OFL',
+		'caption.alt.org.debian' => 'SIL',
+		pat =>
+			qr/$the?(?:SIL )?(?:OPEN FONT LICENSE|[Oo]pen [Ff]ont [Ll]icense)(?: \(OFL\))?/,
+	},
 	python => {
 		name    => 'Python',
 		caption => 'PSF',
@@ -582,13 +640,19 @@ END
 		name    => 'QPL',
 		summary => '$the?Q Public License',
 		pat =>
-			qr/$the?(?:Q Public License(?: \(QPL\))?$by_fsf?|QPL)/,
+			qr/(?:$the?Q Public License(?: \(QPL\))?$by_fsf?|${the}QPL\b)/,
+	},
+	rpsl => {
+		name    => 'RPSL',
+		caption => 'RealNetworks Public Source License',
+		pat =>
+			qr/$the?RealNetworks Public Source License/,
 	},
 	sgi_b => {
 		name    => 'SGI-B',
 		caption => 'SGI Free Software License B',
 		pat =>
-			qr/$the?(?:SGI (?:Free Software License|FREE SOFTWARE LICENSE) B(?: \(SGI-B\))?$by_fsf?|(?:SGI )?FreeB\b|SGI-B)/,
+			qr/(?:$the?SGI (?:Free Software License|FREE SOFTWARE LICENSE) B(?: \(SGI-B\))?$by_fsf?|(?:SGI )?FreeB\b|${the}SGI-B\b)/,
 	},
 	unicode_strict => {
 		name    => 'Unicode-strict',
@@ -605,20 +669,21 @@ END
 		name    => 'WTFPL',
 		caption => 'do What The Fuck you want to Public License',
 		pat =>
-			qr/$the?(?:[Dd]o What The Fuck [Yy]ou [Ww]ant [Tt]o Public License|DO WHAT THE FUCK YOU WANT TO PUBLIC LICENSE(?: \(WTFPL\))?|WTFPL)/,
+			qr/(?:$the?[Dd]o What The Fuck [Yy]ou [Ww]ant [Tt]o Public License|DO WHAT THE FUCK YOU WANT TO PUBLIC LICENSE(?: \(WTFPL\))?|${the}WTFPL\b)/,
 	},
 	zlib => {
 		name    => 'Zlib',
 		caption => 'zlib/libpng',
 		tags    => ['zlib'],
 		pat =>
-			qr/$P{origin_no_misrepresent}.*?$P{derive_altermark}.*?$P{note_invar}/,
+			qr/$P{origin_sw_no_misrepresent}; $P{you_not_claim_wrote}\. $P{use_ack_nonreq}\. $P{altered_srcver_mark}\. $P{notice_no_alter}/,
 	},
 	zlib_acknowledgement => {
-		name    => 'zlib-acknowledgement',
-		caption => 'zlib/libpng with Acknowledgement',
-		tags    => ['zlib'],
-		pat     => qr/$P{origin_no_misrepresent_ack}/,
+		name                => 'NUnit',
+		'name.alt.org.SPDF' => 'zlib-acknowledgement',
+		tags                => ['zlib'],
+		pat =>
+			qr/$P{origin_sw_no_misrepresent}; $P{you_not_claim_wrote}\. $P{use_ack_req}\. Portions Copyright \S+ [\d-]+ Charlie Poole or Copyright \S+ [\d-]+ James W\. Newkirk, Michael C\. Two, Alexei A\. Vorontsov or Copyright \S+ [\d-]+ Philip A\. Craig $P{altered_srcver_mark}\. $P{notice_no_alter}/,
 	},
 );
 
@@ -659,25 +724,25 @@ Patterns each covering a single trait occuring in licenses.
 $RE{'clause_retention'} = {
 	caption => 'retention clause',
 	tags    => ['trait'],
-	pat     => qr/$P{note_retain_notice_cond_discl}/,
+	pat     => qr/$P{retain_notice_cond_discl}/,
 };
 
 $RE{'clause_reproduction'} = {
 	caption => 'reproduction clause',
 	tags    => ['trait'],
-	pat     => qr/$P{note_repro_notice_cond_discl}/,
+	pat     => qr/$P{repro_copr_cond_discl}/,
 };
 
 $RE{'clause_advertising'} = {
 	caption => 'advertising clause',
 	tags    => ['trait'],
-	pat     => qr/$P{ad_verbatim}/,
+	pat     => qr/$P{ad_mat_ack_this}/,
 };
 
 $RE{'clause_advertising_always'} = {
 	caption => 'advertising clause (always)',
 	tags    => ['trait'],
-	pat     => qr/$P{ad_always}/,
+	pat     => qr/$P{redist_ack_this}/,
 };
 
 $RE{'clause_non_endorsement'} = {
@@ -699,31 +764,31 @@ $RE{'fsf_unlimited_retention'} = {
 $RE{'version_later'} = {
 	caption => 'version "or later"',
 	tags    => ['trait'],
-	pat     => qr/,? $P{version_later_postfix}|\. $P{version_later_para}/,
+	pat     => qr/,? $P{ver_later_postfix}|\. $P{ver_later_para}/,
 };
 
 $RE{'version_later_paragraph'} = {
 	caption => 'version "or later" postfix (paragraphs)',
 	tags    => ['trait'],
-	pat     => qr/$P{version_later_para}/,
+	pat     => qr/$P{ver_later_para}/,
 };
 
 $RE{'version_later_postfix'} = {
 	caption => 'version "or later" (postfix)',
 	tags    => ['trait'],
-	pat     => qr/$P{version_later_postfix}/,
+	pat     => qr/$P{ver_later_postfix}/,
 };
 
 $RE{'version_number'} = {
 	caption => 'version number',
 	tags    => ['trait'],
-	pat     => qr/$P{version_number}/,
+	pat     => qr/$P{ver_number}/,
 };
 
 $RE{'version_prefix'} = {
 	caption => 'version prefix',
 	tags    => ['trait'],
-	pat     => qr/$P{version_prefix}/,
+	pat     => qr/$P{ver_prefix}/,
 };
 
 =head2 License combinations
@@ -767,7 +832,7 @@ $RE{'bsd'} = {
 	caption => 'BSD (unspecified)',
 	tags    => ['group'],
 	pat =>
-		qr/$P{note_repro_notice_cond_discl}(?:(?:[^a-zA-Z]+$P{ad_verbatim}.*)?[^a-zA-Z]+$P{nopromo_neither})?/,
+		qr/$P{repro_copr_cond_discl}(?:(?:[\d\W]+$P{ad_mat_ack_this}.*)?[\d\W]+$P{nopromo_neither})?/,
 };
 
 $RE{'gnu'} = {
@@ -781,7 +846,7 @@ $RE{'mit'} = {
 	name    => 'MIT~unspecified',
 	caption => 'MIT (unspecified)',
 	tags    => ['group'],
-	pat     => qr/$the?MIT/,
+	pat     => qr/${the}MIT\b/,
 };
 
 =encoding UTF-8
